pub struct SetAgeIdentityResponse { /* private fields */ }Trait Implementations
Sourceimpl Archive for SetAgeIdentityResponse
impl Archive for SetAgeIdentityResponse
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSetAgeIdentityResponse
type Archived = ArchivedSetAgeIdentityResponse
The archived representation of this type. Read more
Sourcetype Resolver = SetAgeIdentityResponseResolver
type Resolver = SetAgeIdentityResponseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Debug for SetAgeIdentityResponse
impl Debug for SetAgeIdentityResponse
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SetAgeIdentityResponse, __D> for Archived<SetAgeIdentityResponse>
impl<__D: Fallible + ?Sized> Deserialize<SetAgeIdentityResponse, __D> for Archived<SetAgeIdentityResponse>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SetAgeIdentityResponse, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SetAgeIdentityResponse, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl PartialEq for SetAgeIdentityResponse
impl PartialEq for SetAgeIdentityResponse
impl StructuralPartialEq for SetAgeIdentityResponse